@@ -1,13 +1,24 @@
+# -*- encoding: utf-8 -*-
 # pylint: disable-msg=W0622
 """cubicweb-tracker application packaging information
 
-Copyright (c) 2003-2011 LOGILAB S.A. (Paris, FRANCE).
+Copyright (c) 2003-2013 LOGILAB S.A. (Paris, FRANCE).
 http://www.logilab.fr/ -- mailto:contact@logilab.fr
+
+---
+
+The Entypo pictograms are licensed under CC BY 3.0 and the font under
+SIL Open Font License.
+
+The rights to each pictogram in the social extention are either
+trademarked or copyrighted by the respective company.
+
+Entypo pictograms by Daniel Bruce — www.entypo.com
 """
 modname = 'tracker'
 distname = 'cubicweb-tracker'
 
-numversion = (1, 12, 0)
+numversion = (1, 12, 1)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
