@@ -11,14 +11,13 @@ _ = unicode
 from yams.constraints import SizeConstraint
 from yams.buildobjs import (
     EntityType, RelationType, RelationDefinition,
-    SubjectRelation, ObjectRelation, RichString, String, Date)
+    SubjectRelation, RichString, String, Date)
 
 from cubicweb.schema import (
     RQLConstraint, RQLVocabularyConstraint,
     ERQLExpression, RRQLExpression, WorkflowableEntityType)
 
-from cubes.tracker.schemaperms import (
-    sexpr, oexpr, xexpr, restricted_oexpr, xperm)
+from cubes.localperms import sexpr, oexpr, xexpr, restricted_oexpr, xperm
 
 
 class Project(EntityType):
@@ -150,22 +149,14 @@ class see_also(RelationDefinition):
     object = ('Project', 'Ticket')
 
 
+class granted_permission(RelationDefinition):
+    subject = 'Project'
+    object = 'CWPermission'
+
 class require_permission(RelationDefinition):
     subject = ('Project', 'Version', 'Ticket')
     object = 'CWPermission'
 
-class has_group_permission(RelationDefinition):
-    """short cut relation for 'U in_group G, P require_group G' for efficiency
-    reason. This relation is set automatically, you should not set this.
-    """
-    subject = 'CWUser'
-    object = 'CWPermission'
-    __permissions__ = {
-        'read':   ('managers', 'users', 'guests'),
-        'add':    ('managers',),
-        'delete': ('managers',),
-        }
-
 # relation types permissions ##################################################
 
 class subproject_of(RelationType):
