@@ -30,7 +30,8 @@ else:
 
         def _version_sort_value(text):
             try:
-                return sum((10000, 100, 1)[i]*int(v) for i, v in enumerate(text.split(".")))
+                version, _sep, revision = text.partition('-')
+                return sum([1000000,10000,100][i]*int(v) for i, v in enumerate(version.split("."))) + int(revision or 0)
             except (ValueError, IndexError, AttributeError):
                 return 0
         cnx.create_function("VERSION_SORT_VALUE", 1, _version_sort_value)
