@@ -92,9 +92,10 @@ class TicketInContextView(baseviews.OneLineView):
     def cell_call(self, row, col):
         self._cw.add_css('cubes.tracker.css')
         entity = self.cw_rset.get_entity(row, col)
-        self.w(tags.a(entity.dc_title(), href=entity.absolute_url(),
+        self.w(tags.a(entity.dc_title(),
+                      href=entity.absolute_url(),
                       title=uilib.cut(entity.dc_description(), 80),
-                      klass=entity.priority))
+                      klass="%s ticket_%s" % (entity.priority, entity.type)))
 
 
 class StatusSheetTicketView(EntityView):
